package VMOMI::DatastoreAccessible;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
